#!/bin/bash
#
# This script monitors the usage, fairshare, and level fairshare.
# It is meant to be appended upon every submitted job to record the usage.
# 
# It records date in UTC to avoid the headaches if I use this script in Finland 
# or whatever
#
# This file will create a CSV with the recorded usage upon every launched job
#
# Pablo Goitia Gonzalez
# Manuel Gimenez de Castro Marciani
# BSC-CNS - Earth Sciences, 2024

# record current time in UTC and following ISO8601 format :)
DATE=$(date --utc -Iseconds)

# pick rawusage, which is in core seconds, the current fairshare, and the fairshare 
# among users in our group. -h flag to avoid having headers, -P to separate metrics with
# "|", and -U to pick the metrics associated to the current user.
# sed command is used to replace '|' for ','.
SLURM_OUT=$(sshare --format=RawUsage,FairShare,LevelFS -h -A p200191 -P -U | sed -r -e "s/[ \|\ ]+/,/g")

JOB_NAME=$(basename $job_name_ptrn)
EXPID=$(echo $JOB_NAME | cut -d'_' -f1)
OUTPUT_FILE="$(dirname $job_name_ptrn)/${EXPID}_SLURM_DATA.csv"

# if the output file does not exists, creates it
if [ ! -f $OUTPUT_FILE ]; then
    echo "Job Name,Start Time,Raw Usage,Fair Share,Level FS" > $OUTPUT_FILE
fi

# append to the output file
echo "$JOB_NAME,$DATE,$SLURM_OUT" >> $OUTPUT_FILE

